# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class VideoRecordingPart(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'size': 'int',
        'buffer_index': 'int',
        'buffer_runningtime': 'int',
        'file_name': 'str',
        'mp4_file': 'str',
        'sync_start': 'datetime',
        'sync_end': 'datetime',
        'video_recording': 'str',
        'user': 'int'
    }

    attribute_map = {
        'id': 'id',
        'size': 'size',
        'buffer_index': 'buffer_index',
        'buffer_runningtime': 'buffer_runningtime',
        'file_name': 'file_name',
        'mp4_file': 'mp4_file',
        'sync_start': 'sync_start',
        'sync_end': 'sync_end',
        'video_recording': 'video_recording',
        'user': 'user'
    }

    def __init__(self, id=None, size=None, buffer_index=None, buffer_runningtime=None, file_name=None, mp4_file=None, sync_start=None, sync_end=None, video_recording=None, user=None, local_vars_configuration=None):  # noqa: E501
        """VideoRecordingPart - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._size = None
        self._buffer_index = None
        self._buffer_runningtime = None
        self._file_name = None
        self._mp4_file = None
        self._sync_start = None
        self._sync_end = None
        self._video_recording = None
        self._user = None
        self.discriminator = None

        self.id = id
        self.size = size
        self.buffer_index = buffer_index
        self.buffer_runningtime = buffer_runningtime
        self.file_name = file_name
        self.mp4_file = mp4_file
        self.sync_start = sync_start
        self.sync_end = sync_end
        self.video_recording = video_recording
        self.user = user

    @property
    def id(self):
        """Gets the id of this VideoRecordingPart.  # noqa: E501


        :return: The id of this VideoRecordingPart.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this VideoRecordingPart.


        :param id: The id of this VideoRecordingPart.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                id is not None and len(id) > 255):
            raise ValueError("Invalid value for `id`, length must be less than or equal to `255`")  # noqa: E501

        self._id = id

    @property
    def size(self):
        """Gets the size of this VideoRecordingPart.  # noqa: E501


        :return: The size of this VideoRecordingPart.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this VideoRecordingPart.


        :param size: The size of this VideoRecordingPart.  # noqa: E501
        :type size: int
        """
        if self.local_vars_configuration.client_side_validation and size is None:  # noqa: E501
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                size is not None and size > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `size`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                size is not None and size < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `size`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._size = size

    @property
    def buffer_index(self):
        """Gets the buffer_index of this VideoRecordingPart.  # noqa: E501


        :return: The buffer_index of this VideoRecordingPart.  # noqa: E501
        :rtype: int
        """
        return self._buffer_index

    @buffer_index.setter
    def buffer_index(self, buffer_index):
        """Sets the buffer_index of this VideoRecordingPart.


        :param buffer_index: The buffer_index of this VideoRecordingPart.  # noqa: E501
        :type buffer_index: int
        """
        if self.local_vars_configuration.client_side_validation and buffer_index is None:  # noqa: E501
            raise ValueError("Invalid value for `buffer_index`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                buffer_index is not None and buffer_index > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `buffer_index`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                buffer_index is not None and buffer_index < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `buffer_index`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._buffer_index = buffer_index

    @property
    def buffer_runningtime(self):
        """Gets the buffer_runningtime of this VideoRecordingPart.  # noqa: E501


        :return: The buffer_runningtime of this VideoRecordingPart.  # noqa: E501
        :rtype: int
        """
        return self._buffer_runningtime

    @buffer_runningtime.setter
    def buffer_runningtime(self, buffer_runningtime):
        """Sets the buffer_runningtime of this VideoRecordingPart.


        :param buffer_runningtime: The buffer_runningtime of this VideoRecordingPart.  # noqa: E501
        :type buffer_runningtime: int
        """
        if self.local_vars_configuration.client_side_validation and buffer_runningtime is None:  # noqa: E501
            raise ValueError("Invalid value for `buffer_runningtime`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                buffer_runningtime is not None and buffer_runningtime > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `buffer_runningtime`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                buffer_runningtime is not None and buffer_runningtime < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `buffer_runningtime`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._buffer_runningtime = buffer_runningtime

    @property
    def file_name(self):
        """Gets the file_name of this VideoRecordingPart.  # noqa: E501


        :return: The file_name of this VideoRecordingPart.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this VideoRecordingPart.


        :param file_name: The file_name of this VideoRecordingPart.  # noqa: E501
        :type file_name: str
        """
        if self.local_vars_configuration.client_side_validation and file_name is None:  # noqa: E501
            raise ValueError("Invalid value for `file_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                file_name is not None and len(file_name) > 255):
            raise ValueError("Invalid value for `file_name`, length must be less than or equal to `255`")  # noqa: E501

        self._file_name = file_name

    @property
    def mp4_file(self):
        """Gets the mp4_file of this VideoRecordingPart.  # noqa: E501


        :return: The mp4_file of this VideoRecordingPart.  # noqa: E501
        :rtype: str
        """
        return self._mp4_file

    @mp4_file.setter
    def mp4_file(self, mp4_file):
        """Sets the mp4_file of this VideoRecordingPart.


        :param mp4_file: The mp4_file of this VideoRecordingPart.  # noqa: E501
        :type mp4_file: str
        """
        if self.local_vars_configuration.client_side_validation and mp4_file is None:  # noqa: E501
            raise ValueError("Invalid value for `mp4_file`, must not be `None`")  # noqa: E501

        self._mp4_file = mp4_file

    @property
    def sync_start(self):
        """Gets the sync_start of this VideoRecordingPart.  # noqa: E501


        :return: The sync_start of this VideoRecordingPart.  # noqa: E501
        :rtype: datetime
        """
        return self._sync_start

    @sync_start.setter
    def sync_start(self, sync_start):
        """Sets the sync_start of this VideoRecordingPart.


        :param sync_start: The sync_start of this VideoRecordingPart.  # noqa: E501
        :type sync_start: datetime
        """
        if self.local_vars_configuration.client_side_validation and sync_start is None:  # noqa: E501
            raise ValueError("Invalid value for `sync_start`, must not be `None`")  # noqa: E501

        self._sync_start = sync_start

    @property
    def sync_end(self):
        """Gets the sync_end of this VideoRecordingPart.  # noqa: E501


        :return: The sync_end of this VideoRecordingPart.  # noqa: E501
        :rtype: datetime
        """
        return self._sync_end

    @sync_end.setter
    def sync_end(self, sync_end):
        """Sets the sync_end of this VideoRecordingPart.


        :param sync_end: The sync_end of this VideoRecordingPart.  # noqa: E501
        :type sync_end: datetime
        """
        if self.local_vars_configuration.client_side_validation and sync_end is None:  # noqa: E501
            raise ValueError("Invalid value for `sync_end`, must not be `None`")  # noqa: E501

        self._sync_end = sync_end

    @property
    def video_recording(self):
        """Gets the video_recording of this VideoRecordingPart.  # noqa: E501


        :return: The video_recording of this VideoRecordingPart.  # noqa: E501
        :rtype: str
        """
        return self._video_recording

    @video_recording.setter
    def video_recording(self, video_recording):
        """Sets the video_recording of this VideoRecordingPart.


        :param video_recording: The video_recording of this VideoRecordingPart.  # noqa: E501
        :type video_recording: str
        """
        if self.local_vars_configuration.client_side_validation and video_recording is None:  # noqa: E501
            raise ValueError("Invalid value for `video_recording`, must not be `None`")  # noqa: E501

        self._video_recording = video_recording

    @property
    def user(self):
        """Gets the user of this VideoRecordingPart.  # noqa: E501


        :return: The user of this VideoRecordingPart.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this VideoRecordingPart.


        :param user: The user of this VideoRecordingPart.  # noqa: E501
        :type user: int
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoRecordingPart):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VideoRecordingPart):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class OctoPrintBackup(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'deleted': 'datetime',
        'created_dt': 'datetime',
        'hostname': 'str',
        'name': 'str',
        'octoprint_version': 'str',
        'file': 'str',
        'user': 'int'
    }

    attribute_map = {
        'id': 'id',
        'deleted': 'deleted',
        'created_dt': 'created_dt',
        'hostname': 'hostname',
        'name': 'name',
        'octoprint_version': 'octoprint_version',
        'file': 'file',
        'user': 'user'
    }

    def __init__(self, id=None, deleted=None, created_dt=None, hostname=None, name=None, octoprint_version=None, file=None, user=None, local_vars_configuration=None):  # noqa: E501
        """OctoPrintBackup - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._deleted = None
        self._created_dt = None
        self._hostname = None
        self._name = None
        self._octoprint_version = None
        self._file = None
        self._user = None
        self.discriminator = None

        self.id = id
        self.deleted = deleted
        self.created_dt = created_dt
        self.hostname = hostname
        self.name = name
        self.octoprint_version = octoprint_version
        self.file = file
        self.user = user

    @property
    def id(self):
        """Gets the id of this OctoPrintBackup.  # noqa: E501


        :return: The id of this OctoPrintBackup.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OctoPrintBackup.


        :param id: The id of this OctoPrintBackup.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def deleted(self):
        """Gets the deleted of this OctoPrintBackup.  # noqa: E501


        :return: The deleted of this OctoPrintBackup.  # noqa: E501
        :rtype: datetime
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this OctoPrintBackup.


        :param deleted: The deleted of this OctoPrintBackup.  # noqa: E501
        :type deleted: datetime
        """
        if self.local_vars_configuration.client_side_validation and deleted is None:  # noqa: E501
            raise ValueError("Invalid value for `deleted`, must not be `None`")  # noqa: E501

        self._deleted = deleted

    @property
    def created_dt(self):
        """Gets the created_dt of this OctoPrintBackup.  # noqa: E501


        :return: The created_dt of this OctoPrintBackup.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OctoPrintBackup.


        :param created_dt: The created_dt of this OctoPrintBackup.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def hostname(self):
        """Gets the hostname of this OctoPrintBackup.  # noqa: E501


        :return: The hostname of this OctoPrintBackup.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """Sets the hostname of this OctoPrintBackup.


        :param hostname: The hostname of this OctoPrintBackup.  # noqa: E501
        :type hostname: str
        """
        if self.local_vars_configuration.client_side_validation and hostname is None:  # noqa: E501
            raise ValueError("Invalid value for `hostname`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                hostname is not None and len(hostname) > 64):
            raise ValueError("Invalid value for `hostname`, length must be less than or equal to `64`")  # noqa: E501

        self._hostname = hostname

    @property
    def name(self):
        """Gets the name of this OctoPrintBackup.  # noqa: E501


        :return: The name of this OctoPrintBackup.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OctoPrintBackup.


        :param name: The name of this OctoPrintBackup.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501

        self._name = name

    @property
    def octoprint_version(self):
        """Gets the octoprint_version of this OctoPrintBackup.  # noqa: E501


        :return: The octoprint_version of this OctoPrintBackup.  # noqa: E501
        :rtype: str
        """
        return self._octoprint_version

    @octoprint_version.setter
    def octoprint_version(self, octoprint_version):
        """Sets the octoprint_version of this OctoPrintBackup.


        :param octoprint_version: The octoprint_version of this OctoPrintBackup.  # noqa: E501
        :type octoprint_version: str
        """
        if self.local_vars_configuration.client_side_validation and octoprint_version is None:  # noqa: E501
            raise ValueError("Invalid value for `octoprint_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                octoprint_version is not None and len(octoprint_version) > 64):
            raise ValueError("Invalid value for `octoprint_version`, length must be less than or equal to `64`")  # noqa: E501

        self._octoprint_version = octoprint_version

    @property
    def file(self):
        """Gets the file of this OctoPrintBackup.  # noqa: E501


        :return: The file of this OctoPrintBackup.  # noqa: E501
        :rtype: str
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this OctoPrintBackup.


        :param file: The file of this OctoPrintBackup.  # noqa: E501
        :type file: str
        """
        if self.local_vars_configuration.client_side_validation and file is None:  # noqa: E501
            raise ValueError("Invalid value for `file`, must not be `None`")  # noqa: E501

        self._file = file

    @property
    def user(self):
        """Gets the user of this OctoPrintBackup.  # noqa: E501


        :return: The user of this OctoPrintBackup.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this OctoPrintBackup.


        :param user: The user of this OctoPrintBackup.  # noqa: E501
        :type user: int
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OctoPrintBackup):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OctoPrintBackup):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.octo_print_server import OctoPrintServer  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestOctoPrintServer(unittest.TestCase):
    """OctoPrintServer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OctoPrintServer
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.octo_print_server.OctoPrintServer()  # noqa: E501
        if include_optional :
            return OctoPrintServer(
                id = 56, 
                settings = None, 
                base_url = '', 
                base_path = '', 
                venv_path = '', 
                pip_path = '', 
                python_path = '', 
                octoprint_version = '', 
                pip_version = '', 
                python_version = '', 
                printnanny_plugin_version = '', 
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                api_key = '', 
                user = 56, 
                pi = 56
            )
        else :
            return OctoPrintServer(
                id = 56,
                settings = None,
                base_url = '',
                base_path = '',
                venv_path = '',
                pip_path = '',
                python_path = '',
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                user = 56,
                pi = 56,
        )

    def testOctoPrintServer(self):
        """Test OctoPrintServer"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.paginated_pi_list import PaginatedPiList  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestPaginatedPiList(unittest.TestCase):
    """PaginatedPiList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaginatedPiList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.paginated_pi_list.PaginatedPiList()  # noqa: E501
        if include_optional :
            return PaginatedPiList(
                count = 123, 
                next = 'http://api.example.org/accounts/?page=4', 
                previous = 'http://api.example.org/accounts/?page=2', 
                results = [
                    printnanny_api_client.models.pi.Pi(
                        id = 56, 
                        last_boot = '', 
                        network_settings = null, 
                        user = null, 
                        system_info = null, 
                        webrtc_edge = null, 
                        webrtc_cloud = null, 
                        octoprint_server = null, 
                        hostname = '', 
                        favorite = True, 
                        sbc = 'rpi_4', 
                        setup_finished = True, 
                        nats_app = null, 
                        urls = printnanny_api_client.models.pi_urls.Pi_urls(
                            moonraker_api = '', 
                            mission_control = '', 
                            octoprint = '', 
                            swupdate = '', 
                            syncthing = '', ), 
                        shortname_urls = printnanny_api_client.models.pi_urls.Pi_urls(
                            moonraker_api = '', 
                            mission_control = '', 
                            octoprint = '', 
                            swupdate = '', 
                            syncthing = '', ), 
                        mdns_urls = printnanny_api_client.models.pi_urls.Pi_urls(
                            moonraker_api = '', 
                            mission_control = '', 
                            octoprint = '', 
                            swupdate = '', 
                            syncthing = '', ), 
                        created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else :
            return PaginatedPiList(
        )

    def testPaginatedPiList(self):
        """Test PaginatedPiList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class PatchedSystemInfoRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'machine_id': 'str',
        'revision': 'str',
        'model': 'str',
        'serial': 'str',
        'cores': 'int',
        'ram': 'int',
        'os_version_id': 'str',
        'os_build_id': 'str',
        'os_release_json': 'dict(str, object)',
        'uptime': 'int',
        'rootfs_size': 'int',
        'rootfs_used': 'int',
        'bootfs_size': 'int',
        'bootfs_used': 'int',
        'datafs_size': 'int',
        'datafs_used': 'int',
        'pi': 'int'
    }

    attribute_map = {
        'machine_id': 'machine_id',
        'revision': 'revision',
        'model': 'model',
        'serial': 'serial',
        'cores': 'cores',
        'ram': 'ram',
        'os_version_id': 'os_version_id',
        'os_build_id': 'os_build_id',
        'os_release_json': 'os_release_json',
        'uptime': 'uptime',
        'rootfs_size': 'rootfs_size',
        'rootfs_used': 'rootfs_used',
        'bootfs_size': 'bootfs_size',
        'bootfs_used': 'bootfs_used',
        'datafs_size': 'datafs_size',
        'datafs_used': 'datafs_used',
        'pi': 'pi'
    }

    def __init__(self, machine_id=None, revision=None, model=None, serial=None, cores=None, ram=None, os_version_id=None, os_build_id=None, os_release_json=None, uptime=None, rootfs_size=None, rootfs_used=None, bootfs_size=None, bootfs_used=None, datafs_size=None, datafs_used=None, pi=None, local_vars_configuration=None):  # noqa: E501
        """PatchedSystemInfoRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._machine_id = None
        self._revision = None
        self._model = None
        self._serial = None
        self._cores = None
        self._ram = None
        self._os_version_id = None
        self._os_build_id = None
        self._os_release_json = None
        self._uptime = None
        self._rootfs_size = None
        self._rootfs_used = None
        self._bootfs_size = None
        self._bootfs_used = None
        self._datafs_size = None
        self._datafs_used = None
        self._pi = None
        self.discriminator = None

        if machine_id is not None:
            self.machine_id = machine_id
        if revision is not None:
            self.revision = revision
        if model is not None:
            self.model = model
        if serial is not None:
            self.serial = serial
        if cores is not None:
            self.cores = cores
        if ram is not None:
            self.ram = ram
        if os_version_id is not None:
            self.os_version_id = os_version_id
        if os_build_id is not None:
            self.os_build_id = os_build_id
        if os_release_json is not None:
            self.os_release_json = os_release_json
        if uptime is not None:
            self.uptime = uptime
        if rootfs_size is not None:
            self.rootfs_size = rootfs_size
        if rootfs_used is not None:
            self.rootfs_used = rootfs_used
        if bootfs_size is not None:
            self.bootfs_size = bootfs_size
        if bootfs_used is not None:
            self.bootfs_used = bootfs_used
        if datafs_size is not None:
            self.datafs_size = datafs_size
        if datafs_used is not None:
            self.datafs_used = datafs_used
        if pi is not None:
            self.pi = pi

    @property
    def machine_id(self):
        """Gets the machine_id of this PatchedSystemInfoRequest.  # noqa: E501

        Populated from /etc/machine-id  # noqa: E501

        :return: The machine_id of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._machine_id

    @machine_id.setter
    def machine_id(self, machine_id):
        """Sets the machine_id of this PatchedSystemInfoRequest.

        Populated from /etc/machine-id  # noqa: E501

        :param machine_id: The machine_id of this PatchedSystemInfoRequest.  # noqa: E501
        :type machine_id: str
        """
        if (self.local_vars_configuration.client_side_validation and
                machine_id is not None and len(machine_id) > 255):
            raise ValueError("Invalid value for `machine_id`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                machine_id is not None and len(machine_id) < 1):
            raise ValueError("Invalid value for `machine_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._machine_id = machine_id

    @property
    def revision(self):
        """Gets the revision of this PatchedSystemInfoRequest.  # noqa: E501

        Populated from /proc/cpuinfo REVISION  # noqa: E501

        :return: The revision of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this PatchedSystemInfoRequest.

        Populated from /proc/cpuinfo REVISION  # noqa: E501

        :param revision: The revision of this PatchedSystemInfoRequest.  # noqa: E501
        :type revision: str
        """
        if (self.local_vars_configuration.client_side_validation and
                revision is not None and len(revision) > 255):
            raise ValueError("Invalid value for `revision`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                revision is not None and len(revision) < 1):
            raise ValueError("Invalid value for `revision`, length must be greater than or equal to `1`")  # noqa: E501

        self._revision = revision

    @property
    def model(self):
        """Gets the model of this PatchedSystemInfoRequest.  # noqa: E501

        Populated from /proc/cpuinfo MODEL  # noqa: E501

        :return: The model of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this PatchedSystemInfoRequest.

        Populated from /proc/cpuinfo MODEL  # noqa: E501

        :param model: The model of this PatchedSystemInfoRequest.  # noqa: E501
        :type model: str
        """
        if (self.local_vars_configuration.client_side_validation and
                model is not None and len(model) > 255):
            raise ValueError("Invalid value for `model`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                model is not None and len(model) < 1):
            raise ValueError("Invalid value for `model`, length must be greater than or equal to `1`")  # noqa: E501

        self._model = model

    @property
    def serial(self):
        """Gets the serial of this PatchedSystemInfoRequest.  # noqa: E501

        Populated from /proc/cpuinfo SERIAL  # noqa: E501

        :return: The serial of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._serial

    @serial.setter
    def serial(self, serial):
        """Sets the serial of this PatchedSystemInfoRequest.

        Populated from /proc/cpuinfo SERIAL  # noqa: E501

        :param serial: The serial of this PatchedSystemInfoRequest.  # noqa: E501
        :type serial: str
        """
        if (self.local_vars_configuration.client_side_validation and
                serial is not None and len(serial) > 255):
            raise ValueError("Invalid value for `serial`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                serial is not None and len(serial) < 1):
            raise ValueError("Invalid value for `serial`, length must be greater than or equal to `1`")  # noqa: E501

        self._serial = serial

    @property
    def cores(self):
        """Gets the cores of this PatchedSystemInfoRequest.  # noqa: E501


        :return: The cores of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._cores

    @cores.setter
    def cores(self, cores):
        """Sets the cores of this PatchedSystemInfoRequest.


        :param cores: The cores of this PatchedSystemInfoRequest.  # noqa: E501
        :type cores: int
        """
        if (self.local_vars_configuration.client_side_validation and
                cores is not None and cores > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `cores`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                cores is not None and cores < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `cores`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._cores = cores

    @property
    def ram(self):
        """Gets the ram of this PatchedSystemInfoRequest.  # noqa: E501


        :return: The ram of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._ram

    @ram.setter
    def ram(self, ram):
        """Sets the ram of this PatchedSystemInfoRequest.


        :param ram: The ram of this PatchedSystemInfoRequest.  # noqa: E501
        :type ram: int
        """
        if (self.local_vars_configuration.client_side_validation and
                ram is not None and ram > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `ram`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                ram is not None and ram < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `ram`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._ram = ram

    @property
    def os_version_id(self):
        """Gets the os_version_id of this PatchedSystemInfoRequest.  # noqa: E501

        PrintNanny OS VERSION_ID from /etc/os-release  # noqa: E501

        :return: The os_version_id of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._os_version_id

    @os_version_id.setter
    def os_version_id(self, os_version_id):
        """Sets the os_version_id of this PatchedSystemInfoRequest.

        PrintNanny OS VERSION_ID from /etc/os-release  # noqa: E501

        :param os_version_id: The os_version_id of this PatchedSystemInfoRequest.  # noqa: E501
        :type os_version_id: str
        """
        if (self.local_vars_configuration.client_side_validation and
                os_version_id is not None and len(os_version_id) > 255):
            raise ValueError("Invalid value for `os_version_id`, length must be less than or equal to `255`")  # noqa: E501

        self._os_version_id = os_version_id

    @property
    def os_build_id(self):
        """Gets the os_build_id of this PatchedSystemInfoRequest.  # noqa: E501

        PrintNanny OS BUILD_ID from /etc/os-release  # noqa: E501

        :return: The os_build_id of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._os_build_id

    @os_build_id.setter
    def os_build_id(self, os_build_id):
        """Sets the os_build_id of this PatchedSystemInfoRequest.

        PrintNanny OS BUILD_ID from /etc/os-release  # noqa: E501

        :param os_build_id: The os_build_id of this PatchedSystemInfoRequest.  # noqa: E501
        :type os_build_id: str
        """
        if (self.local_vars_configuration.client_side_validation and
                os_build_id is not None and len(os_build_id) > 255):
            raise ValueError("Invalid value for `os_build_id`, length must be less than or equal to `255`")  # noqa: E501

        self._os_build_id = os_build_id

    @property
    def os_release_json(self):
        """Gets the os_release_json of this PatchedSystemInfoRequest.  # noqa: E501

        Full contents of /etc/os-release in key:value format  # noqa: E501

        :return: The os_release_json of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._os_release_json

    @os_release_json.setter
    def os_release_json(self, os_release_json):
        """Sets the os_release_json of this PatchedSystemInfoRequest.

        Full contents of /etc/os-release in key:value format  # noqa: E501

        :param os_release_json: The os_release_json of this PatchedSystemInfoRequest.  # noqa: E501
        :type os_release_json: dict(str, object)
        """

        self._os_release_json = os_release_json

    @property
    def uptime(self):
        """Gets the uptime of this PatchedSystemInfoRequest.  # noqa: E501

        system uptime (in seconds)  # noqa: E501

        :return: The uptime of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._uptime

    @uptime.setter
    def uptime(self, uptime):
        """Sets the uptime of this PatchedSystemInfoRequest.

        system uptime (in seconds)  # noqa: E501

        :param uptime: The uptime of this PatchedSystemInfoRequest.  # noqa: E501
        :type uptime: int
        """
        if (self.local_vars_configuration.client_side_validation and
                uptime is not None and uptime > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `uptime`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                uptime is not None and uptime < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `uptime`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._uptime = uptime

    @property
    def rootfs_size(self):
        """Gets the rootfs_size of this PatchedSystemInfoRequest.  # noqa: E501

        Size of /dev/root filesystem in bytes  # noqa: E501

        :return: The rootfs_size of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._rootfs_size

    @rootfs_size.setter
    def rootfs_size(self, rootfs_size):
        """Sets the rootfs_size of this PatchedSystemInfoRequest.

        Size of /dev/root filesystem in bytes  # noqa: E501

        :param rootfs_size: The rootfs_size of this PatchedSystemInfoRequest.  # noqa: E501
        :type rootfs_size: int
        """
        if (self.local_vars_configuration.client_side_validation and
                rootfs_size is not None and rootfs_size > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `rootfs_size`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                rootfs_size is not None and rootfs_size < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `rootfs_size`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._rootfs_size = rootfs_size

    @property
    def rootfs_used(self):
        """Gets the rootfs_used of this PatchedSystemInfoRequest.  # noqa: E501

        Space used in /dev/root filesystem in bytes  # noqa: E501

        :return: The rootfs_used of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._rootfs_used

    @rootfs_used.setter
    def rootfs_used(self, rootfs_used):
        """Sets the rootfs_used of this PatchedSystemInfoRequest.

        Space used in /dev/root filesystem in bytes  # noqa: E501

        :param rootfs_used: The rootfs_used of this PatchedSystemInfoRequest.  # noqa: E501
        :type rootfs_used: int
        """
        if (self.local_vars_configuration.client_side_validation and
                rootfs_used is not None and rootfs_used > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `rootfs_used`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                rootfs_used is not None and rootfs_used < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `rootfs_used`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._rootfs_used = rootfs_used

    @property
    def bootfs_size(self):
        """Gets the bootfs_size of this PatchedSystemInfoRequest.  # noqa: E501

        Size of /dev/mmcblk0p1 filesystem in bytes  # noqa: E501

        :return: The bootfs_size of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._bootfs_size

    @bootfs_size.setter
    def bootfs_size(self, bootfs_size):
        """Sets the bootfs_size of this PatchedSystemInfoRequest.

        Size of /dev/mmcblk0p1 filesystem in bytes  # noqa: E501

        :param bootfs_size: The bootfs_size of this PatchedSystemInfoRequest.  # noqa: E501
        :type bootfs_size: int
        """
        if (self.local_vars_configuration.client_side_validation and
                bootfs_size is not None and bootfs_size > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `bootfs_size`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                bootfs_size is not None and bootfs_size < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `bootfs_size`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._bootfs_size = bootfs_size

    @property
    def bootfs_used(self):
        """Gets the bootfs_used of this PatchedSystemInfoRequest.  # noqa: E501

        Space used in /dev/mmcblk0p1 filesystem in bytes  # noqa: E501

        :return: The bootfs_used of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._bootfs_used

    @bootfs_used.setter
    def bootfs_used(self, bootfs_used):
        """Sets the bootfs_used of this PatchedSystemInfoRequest.

        Space used in /dev/mmcblk0p1 filesystem in bytes  # noqa: E501

        :param bootfs_used: The bootfs_used of this PatchedSystemInfoRequest.  # noqa: E501
        :type bootfs_used: int
        """
        if (self.local_vars_configuration.client_side_validation and
                bootfs_used is not None and bootfs_used > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `bootfs_used`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                bootfs_used is not None and bootfs_used < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `bootfs_used`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._bootfs_used = bootfs_used

    @property
    def datafs_size(self):
        """Gets the datafs_size of this PatchedSystemInfoRequest.  # noqa: E501

        Size of /dev/mmcblk0p4 filesystem in bytes  # noqa: E501

        :return: The datafs_size of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._datafs_size

    @datafs_size.setter
    def datafs_size(self, datafs_size):
        """Sets the datafs_size of this PatchedSystemInfoRequest.

        Size of /dev/mmcblk0p4 filesystem in bytes  # noqa: E501

        :param datafs_size: The datafs_size of this PatchedSystemInfoRequest.  # noqa: E501
        :type datafs_size: int
        """
        if (self.local_vars_configuration.client_side_validation and
                datafs_size is not None and datafs_size > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `datafs_size`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                datafs_size is not None and datafs_size < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `datafs_size`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._datafs_size = datafs_size

    @property
    def datafs_used(self):
        """Gets the datafs_used of this PatchedSystemInfoRequest.  # noqa: E501

        Space used in /dev/mmcblk0p4 filesystem in bytes  # noqa: E501

        :return: The datafs_used of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._datafs_used

    @datafs_used.setter
    def datafs_used(self, datafs_used):
        """Sets the datafs_used of this PatchedSystemInfoRequest.

        Space used in /dev/mmcblk0p4 filesystem in bytes  # noqa: E501

        :param datafs_used: The datafs_used of this PatchedSystemInfoRequest.  # noqa: E501
        :type datafs_used: int
        """
        if (self.local_vars_configuration.client_side_validation and
                datafs_used is not None and datafs_used > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `datafs_used`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                datafs_used is not None and datafs_used < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `datafs_used`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._datafs_used = datafs_used

    @property
    def pi(self):
        """Gets the pi of this PatchedSystemInfoRequest.  # noqa: E501


        :return: The pi of this PatchedSystemInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._pi

    @pi.setter
    def pi(self, pi):
        """Sets the pi of this PatchedSystemInfoRequest.


        :param pi: The pi of this PatchedSystemInfoRequest.  # noqa: E501
        :type pi: int
        """

        self._pi = pi

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PatchedSystemInfoRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PatchedSystemInfoRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class MoonrakerServerRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'base_path': 'str',
        'moonraker_version': 'str',
        'pip_version': 'str',
        'python_version': 'str',
        'api_key': 'str',
        'pi': 'int'
    }

    attribute_map = {
        'base_path': 'base_path',
        'moonraker_version': 'moonraker_version',
        'pip_version': 'pip_version',
        'python_version': 'python_version',
        'api_key': 'api_key',
        'pi': 'pi'
    }

    def __init__(self, base_path=None, moonraker_version=None, pip_version=None, python_version=None, api_key=None, pi=None, local_vars_configuration=None):  # noqa: E501
        """MoonrakerServerRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._base_path = None
        self._moonraker_version = None
        self._pip_version = None
        self._python_version = None
        self._api_key = None
        self._pi = None
        self.discriminator = None

        self.base_path = base_path
        if moonraker_version is not None:
            self.moonraker_version = moonraker_version
        if pip_version is not None:
            self.pip_version = pip_version
        if python_version is not None:
            self.python_version = python_version
        self.api_key = api_key
        self.pi = pi

    @property
    def base_path(self):
        """Gets the base_path of this MoonrakerServerRequest.  # noqa: E501


        :return: The base_path of this MoonrakerServerRequest.  # noqa: E501
        :rtype: str
        """
        return self._base_path

    @base_path.setter
    def base_path(self, base_path):
        """Sets the base_path of this MoonrakerServerRequest.


        :param base_path: The base_path of this MoonrakerServerRequest.  # noqa: E501
        :type base_path: str
        """
        if self.local_vars_configuration.client_side_validation and base_path is None:  # noqa: E501
            raise ValueError("Invalid value for `base_path`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                base_path is not None and len(base_path) < 1):
            raise ValueError("Invalid value for `base_path`, length must be greater than or equal to `1`")  # noqa: E501

        self._base_path = base_path

    @property
    def moonraker_version(self):
        """Gets the moonraker_version of this MoonrakerServerRequest.  # noqa: E501


        :return: The moonraker_version of this MoonrakerServerRequest.  # noqa: E501
        :rtype: str
        """
        return self._moonraker_version

    @moonraker_version.setter
    def moonraker_version(self, moonraker_version):
        """Sets the moonraker_version of this MoonrakerServerRequest.


        :param moonraker_version: The moonraker_version of this MoonrakerServerRequest.  # noqa: E501
        :type moonraker_version: str
        """
        if (self.local_vars_configuration.client_side_validation and
                moonraker_version is not None and len(moonraker_version) > 32):
            raise ValueError("Invalid value for `moonraker_version`, length must be less than or equal to `32`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                moonraker_version is not None and len(moonraker_version) < 1):
            raise ValueError("Invalid value for `moonraker_version`, length must be greater than or equal to `1`")  # noqa: E501

        self._moonraker_version = moonraker_version

    @property
    def pip_version(self):
        """Gets the pip_version of this MoonrakerServerRequest.  # noqa: E501


        :return: The pip_version of this MoonrakerServerRequest.  # noqa: E501
        :rtype: str
        """
        return self._pip_version

    @pip_version.setter
    def pip_version(self, pip_version):
        """Sets the pip_version of this MoonrakerServerRequest.


        :param pip_version: The pip_version of this MoonrakerServerRequest.  # noqa: E501
        :type pip_version: str
        """
        if (self.local_vars_configuration.client_side_validation and
                pip_version is not None and len(pip_version) > 32):
            raise ValueError("Invalid value for `pip_version`, length must be less than or equal to `32`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                pip_version is not None and len(pip_version) < 1):
            raise ValueError("Invalid value for `pip_version`, length must be greater than or equal to `1`")  # noqa: E501

        self._pip_version = pip_version

    @property
    def python_version(self):
        """Gets the python_version of this MoonrakerServerRequest.  # noqa: E501


        :return: The python_version of this MoonrakerServerRequest.  # noqa: E501
        :rtype: str
        """
        return self._python_version

    @python_version.setter
    def python_version(self, python_version):
        """Sets the python_version of this MoonrakerServerRequest.


        :param python_version: The python_version of this MoonrakerServerRequest.  # noqa: E501
        :type python_version: str
        """
        if (self.local_vars_configuration.client_side_validation and
                python_version is not None and len(python_version) > 32):
            raise ValueError("Invalid value for `python_version`, length must be less than or equal to `32`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                python_version is not None and len(python_version) < 1):
            raise ValueError("Invalid value for `python_version`, length must be greater than or equal to `1`")  # noqa: E501

        self._python_version = python_version

    @property
    def api_key(self):
        """Gets the api_key of this MoonrakerServerRequest.  # noqa: E501


        :return: The api_key of this MoonrakerServerRequest.  # noqa: E501
        :rtype: str
        """
        return self._api_key

    @api_key.setter
    def api_key(self, api_key):
        """Sets the api_key of this MoonrakerServerRequest.


        :param api_key: The api_key of this MoonrakerServerRequest.  # noqa: E501
        :type api_key: str
        """
        if (self.local_vars_configuration.client_side_validation and
                api_key is not None and len(api_key) > 255):
            raise ValueError("Invalid value for `api_key`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                api_key is not None and len(api_key) < 1):
            raise ValueError("Invalid value for `api_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._api_key = api_key

    @property
    def pi(self):
        """Gets the pi of this MoonrakerServerRequest.  # noqa: E501


        :return: The pi of this MoonrakerServerRequest.  # noqa: E501
        :rtype: int
        """
        return self._pi

    @pi.setter
    def pi(self, pi):
        """Sets the pi of this MoonrakerServerRequest.


        :param pi: The pi of this MoonrakerServerRequest.  # noqa: E501
        :type pi: int
        """
        if self.local_vars_configuration.client_side_validation and pi is None:  # noqa: E501
            raise ValueError("Invalid value for `pi`, must not be `None`")  # noqa: E501

        self._pi = pi

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MoonrakerServerRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MoonrakerServerRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class PiNatsApp(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'app_name': 'str',
        'json': 'dict(str, object)',
        'pi': 'int',
        'organization': 'NatsOrganization',
        'organization_user': 'int',
        'nats_server_uri': 'str',
        'nats_ws_uri': 'str',
        'nats_subject_pattern': 'str',
        'nats_subject_pattern_template': 'str',
        'mqtt_subject_template_moonraker_request': 'str',
        'mqtt_subject_moonraker_request': 'str',
        'mqtt_subject_template_moonraker_response': 'str',
        'mqtt_subject_moonraker_response': 'str',
        'mqtt_subject_template_klipper_status': 'str',
        'mqtt_subject_klipper_status': 'str',
        'mqtt_broker_host': 'str',
        'mqtt_broker_port': 'int'
    }

    attribute_map = {
        'id': 'id',
        'app_name': 'app_name',
        'json': 'json',
        'pi': 'pi',
        'organization': 'organization',
        'organization_user': 'organization_user',
        'nats_server_uri': 'nats_server_uri',
        'nats_ws_uri': 'nats_ws_uri',
        'nats_subject_pattern': 'nats_subject_pattern',
        'nats_subject_pattern_template': 'nats_subject_pattern_template',
        'mqtt_subject_template_moonraker_request': 'mqtt_subject_template_moonraker_request',
        'mqtt_subject_moonraker_request': 'mqtt_subject_moonraker_request',
        'mqtt_subject_template_moonraker_response': 'mqtt_subject_template_moonraker_response',
        'mqtt_subject_moonraker_response': 'mqtt_subject_moonraker_response',
        'mqtt_subject_template_klipper_status': 'mqtt_subject_template_klipper_status',
        'mqtt_subject_klipper_status': 'mqtt_subject_klipper_status',
        'mqtt_broker_host': 'mqtt_broker_host',
        'mqtt_broker_port': 'mqtt_broker_port'
    }

    def __init__(self, id=None, app_name=None, json=None, pi=None, organization=None, organization_user=None, nats_server_uri=None, nats_ws_uri=None, nats_subject_pattern=None, nats_subject_pattern_template=None, mqtt_subject_template_moonraker_request=None, mqtt_subject_moonraker_request=None, mqtt_subject_template_moonraker_response=None, mqtt_subject_moonraker_response=None, mqtt_subject_template_klipper_status=None, mqtt_subject_klipper_status=None, mqtt_broker_host=None, mqtt_broker_port=None, local_vars_configuration=None):  # noqa: E501
        """PiNatsApp - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._app_name = None
        self._json = None
        self._pi = None
        self._organization = None
        self._organization_user = None
        self._nats_server_uri = None
        self._nats_ws_uri = None
        self._nats_subject_pattern = None
        self._nats_subject_pattern_template = None
        self._mqtt_subject_template_moonraker_request = None
        self._mqtt_subject_moonraker_request = None
        self._mqtt_subject_template_moonraker_response = None
        self._mqtt_subject_moonraker_response = None
        self._mqtt_subject_template_klipper_status = None
        self._mqtt_subject_klipper_status = None
        self._mqtt_broker_host = None
        self._mqtt_broker_port = None
        self.discriminator = None

        self.id = id
        if app_name is not None:
            self.app_name = app_name
        if json is not None:
            self.json = json
        self.pi = pi
        self.organization = organization
        self.organization_user = organization_user
        self.nats_server_uri = nats_server_uri
        self.nats_ws_uri = nats_ws_uri
        self.nats_subject_pattern = nats_subject_pattern
        self.nats_subject_pattern_template = nats_subject_pattern_template
        self.mqtt_subject_template_moonraker_request = mqtt_subject_template_moonraker_request
        self.mqtt_subject_moonraker_request = mqtt_subject_moonraker_request
        self.mqtt_subject_template_moonraker_response = mqtt_subject_template_moonraker_response
        self.mqtt_subject_moonraker_response = mqtt_subject_moonraker_response
        self.mqtt_subject_template_klipper_status = mqtt_subject_template_klipper_status
        self.mqtt_subject_klipper_status = mqtt_subject_klipper_status
        self.mqtt_broker_host = mqtt_broker_host
        self.mqtt_broker_port = mqtt_broker_port

    @property
    def id(self):
        """Gets the id of this PiNatsApp.  # noqa: E501


        :return: The id of this PiNatsApp.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PiNatsApp.


        :param id: The id of this PiNatsApp.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def app_name(self):
        """Gets the app_name of this PiNatsApp.  # noqa: E501


        :return: The app_name of this PiNatsApp.  # noqa: E501
        :rtype: str
        """
        return self._app_name

    @app_name.setter
    def app_name(self, app_name):
        """Sets the app_name of this PiNatsApp.


        :param app_name: The app_name of this PiNatsApp.  # noqa: E501
        :type app_name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                app_name is not None and len(app_name) > 255):
            raise ValueError("Invalid value for `app_name`, length must be less than or equal to `255`")  # noqa: E501

        self._app_name = app_name

    @property
    def json(self):
        """Gets the json of this PiNatsApp.  # noqa: E501

        Output of `nsc describe account`  # noqa: E501

        :return: The json of this PiNatsApp.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this PiNatsApp.

        Output of `nsc describe account`  # noqa: E501

        :param json: The json of this PiNatsApp.  # noqa: E501
        :type json: dict(str, object)
        """

        self._json = json

    @property
    def pi(self):
        """Gets the pi of this PiNatsApp.  # noqa: E501


        :return: The pi of this PiNatsApp.  # noqa: E501
        :rtype: int
        """
        return self._pi

    @pi.setter
    def pi(self, pi):
        """Sets the pi of this PiNatsApp.


        :param pi: The pi of this PiNatsApp.  # noqa: E501
        :type pi: int
        """
        if self.local_vars_configuration.client_side_validation and pi is None:  # noqa: E501
            raise ValueError("Invalid value for `pi`, must not be `None`")  # noqa: E501

        self._pi = pi

    @property
    def organization(self):
        """Gets the organization of this PiNatsApp.  # noqa: E501


        :return: The organization of this PiNatsApp.  # noqa: E501
        :rtype: NatsOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this PiNatsApp.


        :param organization: The organization of this PiNatsApp.  # noqa: E501
        :type organization: NatsOrganization
        """
        if self.local_vars_configuration.client_side_validation and organization is None:  # noqa: E501
            raise ValueError("Invalid value for `organization`, must not be `None`")  # noqa: E501

        self._organization = organization

    @property
    def organization_user(self):
        """Gets the organization_user of this PiNatsApp.  # noqa: E501


        :return: The organization_user of this PiNatsApp.  # noqa: E501
        :rtype: int
        """
        return self._organization_user

    @organization_user.setter
    def organization_user(self, organization_user):
        """Sets the organization_user of this PiNatsApp.


        :param organization_user: The organization_user of this PiNatsApp.  # noqa: E501
        :type organization_user: int
        """
        if self.local_vars_configuration.client_side_validation and organization_user is None:  # noqa: E501
            raise ValueError("Invalid value for `organization_user`, must not be `None`")  # noqa: E501

        self._organization_user = organization_user

    @property
    def nats_server_uri(self):
        """Gets the nats_server_uri of this PiNatsApp.  # noqa: E501


        :return: The nats_server_uri of this PiNatsApp.  # noqa: E501
        :rtype: str
        """
        return self._nats_server_uri

    @nats_server_uri.setter
    def nats_server_uri(self, nats_server_uri):
        """Sets the nats_server_uri of this PiNatsApp.


        :param nats_server_uri: The nats_server_uri of this PiNatsApp.  # noqa: E501
        :type nats_server_uri: str
        """
        if self.local_vars_configuration.client_side_validation and nats_server_uri is None:  # noqa: E501
            raise ValueError("Invalid value for `nats_server_uri`, must not be `None`")  # noqa: E501

        self._nats_server_uri = nats_server_uri

    @property
    def nats_ws_uri(self):
        """Gets the nats_ws_uri of this PiNatsApp.  # noqa: E501


        :return: The nats_ws_uri of this PiNatsApp.  # noqa: E501
        :rtype: str
        """
        return self._nats_ws_uri

    @nats_ws_uri.setter
    def nats_ws_uri(self, nats_ws_uri):
        """Sets the nats_ws_uri of this PiNatsApp.


        :param nats_ws_uri: The nats_ws_uri of this PiNatsApp.  # noqa: E501
        :type nats_ws_uri: str
        """
        if self.local_vars_configuration.client_side_validation and nats_ws_uri is None:  # noqa: E501
            raise ValueError("Invalid value for `nats_ws_uri`, must not be `None`")  # noqa: E501

        self._nats_ws_uri = nats_ws_uri

    @property
    def nats_subject_pattern(self):
        """Gets the nats_subject_pattern of this PiNatsApp.  # noqa: E501


        :return: The nats_subject_pattern of this PiNatsApp.  # noqa: E501
        :rtype: str
        """
        return self._nats_subject_pattern

    @nats_subject_pattern.setter
    def nats_subject_pattern(self, nats_subject_pattern):
        """Sets the nats_subject_pattern of this PiNatsApp.


        :param nats_subject_pattern: The nats_subject_pattern of this PiNatsApp.  # noqa: E501
        :type nats_subject_pattern: str
        """
        if self.local_vars_configuration.client_side_validation and nats_subject_pattern is None:  # noqa: E501
            raise ValueError("Invalid value for `nats_subject_pattern`, must not be `None`")  # noqa: E501

        self._nats_subject_pattern = nats_subject_pattern

    @property
    def nats_subject_pattern_template(self):
        """Gets the nats_subject_pattern_template of this PiNatsApp.  # noqa: E501


        :return: The nats_subject_pattern_template of this PiNatsApp.  # noqa: E501
        :rtype: str
        """
        return self._nats_subject_pattern_template

    @nats_subject_pattern_template.setter
    def nats_subject_pattern_template(self, nats_subject_pattern_template):
        """Sets the nats_subject_pattern_template of this PiNatsApp.


        :param nats_subject_pattern_template: The nats_subject_pattern_template of this PiNatsApp.  # noqa: E501
        :type nats_subject_pattern_template: str
        """
        if self.local_vars_configuration.client_side_validation and nats_subject_pattern_template is None:  # noqa: E501
            raise ValueError("Invalid value for `nats_subject_pattern_template`, must not be `None`")  # noqa: E501

        self._nats_subject_pattern_template = nats_subject_pattern_template

    @property
    def mqtt_subject_template_moonraker_request(self):
        """Gets the mqtt_subject_template_moonraker_request of this PiNatsApp.  # noqa: E501


        :return: The mqtt_subject_template_moonraker_request of this PiNatsApp.  # noqa: E501
        :rtype: str
        """
        return self._mqtt_subject_template_moonraker_request

    @mqtt_subject_template_moonraker_request.setter
    def mqtt_subject_template_moonraker_request(self, mqtt_subject_template_moonraker_request):
        """Sets the mqtt_subject_template_moonraker_request of this PiNatsApp.


        :param mqtt_subject_template_moonraker_request: The mqtt_subject_template_moonraker_request of this PiNatsApp.  # noqa: E501
        :type mqtt_subject_template_moonraker_request: str
        """
        if self.local_vars_configuration.client_side_validation and mqtt_subject_template_moonraker_request is None:  # noqa: E501
            raise ValueError("Invalid value for `mqtt_subject_template_moonraker_request`, must not be `None`")  # noqa: E501

        self._mqtt_subject_template_moonraker_request = mqtt_subject_template_moonraker_request

    @property
    def mqtt_subject_moonraker_request(self):
        """Gets the mqtt_subject_moonraker_request of this PiNatsApp.  # noqa: E501


        :return: The mqtt_subject_moonraker_request of this PiNatsApp.  # noqa: E501
        :rtype: str
        """
        return self._mqtt_subject_moonraker_request

    @mqtt_subject_moonraker_request.setter
    def mqtt_subject_moonraker_request(self, mqtt_subject_moonraker_request):
        """Sets the mqtt_subject_moonraker_request of this PiNatsApp.


        :param mqtt_subject_moonraker_request: The mqtt_subject_moonraker_request of this PiNatsApp.  # noqa: E501
        :type mqtt_subject_moonraker_request: str
        """
        if self.local_vars_configuration.client_side_validation and mqtt_subject_moonraker_request is None:  # noqa: E501
            raise ValueError("Invalid value for `mqtt_subject_moonraker_request`, must not be `None`")  # noqa: E501

        self._mqtt_subject_moonraker_request = mqtt_subject_moonraker_request

    @property
    def mqtt_subject_template_moonraker_response(self):
        """Gets the mqtt_subject_template_moonraker_response of this PiNatsApp.  # noqa: E501


        :return: The mqtt_subject_template_moonraker_response of this PiNatsApp.  # noqa: E501
        :rtype: str
        """
        return self._mqtt_subject_template_moonraker_response

    @mqtt_subject_template_moonraker_response.setter
    def mqtt_subject_template_moonraker_response(self, mqtt_subject_template_moonraker_response):
        """Sets the mqtt_subject_template_moonraker_response of this PiNatsApp.


        :param mqtt_subject_template_moonraker_response: The mqtt_subject_template_moonraker_response of this PiNatsApp.  # noqa: E501
        :type mqtt_subject_template_moonraker_response: str
        """
        if self.local_vars_configuration.client_side_validation and mqtt_subject_template_moonraker_response is None:  # noqa: E501
            raise ValueError("Invalid value for `mqtt_subject_template_moonraker_response`, must not be `None`")  # noqa: E501

        self._mqtt_subject_template_moonraker_response = mqtt_subject_template_moonraker_response

    @property
    def mqtt_subject_moonraker_response(self):
        """Gets the mqtt_subject_moonraker_response of this PiNatsApp.  # noqa: E501


        :return: The mqtt_subject_moonraker_response of this PiNatsApp.  # noqa: E501
        :rtype: str
        """
        return self._mqtt_subject_moonraker_response

    @mqtt_subject_moonraker_response.setter
    def mqtt_subject_moonraker_response(self, mqtt_subject_moonraker_response):
        """Sets the mqtt_subject_moonraker_response of this PiNatsApp.


        :param mqtt_subject_moonraker_response: The mqtt_subject_moonraker_response of this PiNatsApp.  # noqa: E501
        :type mqtt_subject_moonraker_response: str
        """
        if self.local_vars_configuration.client_side_validation and mqtt_subject_moonraker_response is None:  # noqa: E501
            raise ValueError("Invalid value for `mqtt_subject_moonraker_response`, must not be `None`")  # noqa: E501

        self._mqtt_subject_moonraker_response = mqtt_subject_moonraker_response

    @property
    def mqtt_subject_template_klipper_status(self):
        """Gets the mqtt_subject_template_klipper_status of this PiNatsApp.  # noqa: E501


        :return: The mqtt_subject_template_klipper_status of this PiNatsApp.  # noqa: E501
        :rtype: str
        """
        return self._mqtt_subject_template_klipper_status

    @mqtt_subject_template_klipper_status.setter
    def mqtt_subject_template_klipper_status(self, mqtt_subject_template_klipper_status):
        """Sets the mqtt_subject_template_klipper_status of this PiNatsApp.


        :param mqtt_subject_template_klipper_status: The mqtt_subject_template_klipper_status of this PiNatsApp.  # noqa: E501
        :type mqtt_subject_template_klipper_status: str
        """
        if self.local_vars_configuration.client_side_validation and mqtt_subject_template_klipper_status is None:  # noqa: E501
            raise ValueError("Invalid value for `mqtt_subject_template_klipper_status`, must not be `None`")  # noqa: E501

        self._mqtt_subject_template_klipper_status = mqtt_subject_template_klipper_status

    @property
    def mqtt_subject_klipper_status(self):
        """Gets the mqtt_subject_klipper_status of this PiNatsApp.  # noqa: E501


        :return: The mqtt_subject_klipper_status of this PiNatsApp.  # noqa: E501
        :rtype: str
        """
        return self._mqtt_subject_klipper_status

    @mqtt_subject_klipper_status.setter
    def mqtt_subject_klipper_status(self, mqtt_subject_klipper_status):
        """Sets the mqtt_subject_klipper_status of this PiNatsApp.


        :param mqtt_subject_klipper_status: The mqtt_subject_klipper_status of this PiNatsApp.  # noqa: E501
        :type mqtt_subject_klipper_status: str
        """
        if self.local_vars_configuration.client_side_validation and mqtt_subject_klipper_status is None:  # noqa: E501
            raise ValueError("Invalid value for `mqtt_subject_klipper_status`, must not be `None`")  # noqa: E501

        self._mqtt_subject_klipper_status = mqtt_subject_klipper_status

    @property
    def mqtt_broker_host(self):
        """Gets the mqtt_broker_host of this PiNatsApp.  # noqa: E501


        :return: The mqtt_broker_host of this PiNatsApp.  # noqa: E501
        :rtype: str
        """
        return self._mqtt_broker_host

    @mqtt_broker_host.setter
    def mqtt_broker_host(self, mqtt_broker_host):
        """Sets the mqtt_broker_host of this PiNatsApp.


        :param mqtt_broker_host: The mqtt_broker_host of this PiNatsApp.  # noqa: E501
        :type mqtt_broker_host: str
        """
        if self.local_vars_configuration.client_side_validation and mqtt_broker_host is None:  # noqa: E501
            raise ValueError("Invalid value for `mqtt_broker_host`, must not be `None`")  # noqa: E501

        self._mqtt_broker_host = mqtt_broker_host

    @property
    def mqtt_broker_port(self):
        """Gets the mqtt_broker_port of this PiNatsApp.  # noqa: E501


        :return: The mqtt_broker_port of this PiNatsApp.  # noqa: E501
        :rtype: int
        """
        return self._mqtt_broker_port

    @mqtt_broker_port.setter
    def mqtt_broker_port(self, mqtt_broker_port):
        """Sets the mqtt_broker_port of this PiNatsApp.


        :param mqtt_broker_port: The mqtt_broker_port of this PiNatsApp.  # noqa: E501
        :type mqtt_broker_port: int
        """
        if self.local_vars_configuration.client_side_validation and mqtt_broker_port is None:  # noqa: E501
            raise ValueError("Invalid value for `mqtt_broker_port`, must not be `None`")  # noqa: E501

        self._mqtt_broker_port = mqtt_broker_port

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PiNatsApp):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PiNatsApp):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class VideoRecording(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'mp4_upload_url': 'str',
        'mp4_size': 'int',
        'cloud_sync_done': 'bool',
        'finalize_start': 'datetime',
        'finalize_end': 'datetime',
        'recording_start': 'datetime',
        'recording_end': 'datetime',
        'gcode_file_name': 'str',
        'mp4_file': 'str',
        'user': 'int'
    }

    attribute_map = {
        'id': 'id',
        'mp4_upload_url': 'mp4_upload_url',
        'mp4_size': 'mp4_size',
        'cloud_sync_done': 'cloud_sync_done',
        'finalize_start': 'finalize_start',
        'finalize_end': 'finalize_end',
        'recording_start': 'recording_start',
        'recording_end': 'recording_end',
        'gcode_file_name': 'gcode_file_name',
        'mp4_file': 'mp4_file',
        'user': 'user'
    }

    def __init__(self, id=None, mp4_upload_url=None, mp4_size=None, cloud_sync_done=None, finalize_start=None, finalize_end=None, recording_start=None, recording_end=None, gcode_file_name=None, mp4_file=None, user=None, local_vars_configuration=None):  # noqa: E501
        """VideoRecording - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._mp4_upload_url = None
        self._mp4_size = None
        self._cloud_sync_done = None
        self._finalize_start = None
        self._finalize_end = None
        self._recording_start = None
        self._recording_end = None
        self._gcode_file_name = None
        self._mp4_file = None
        self._user = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.mp4_upload_url = mp4_upload_url
        self.mp4_size = mp4_size
        if cloud_sync_done is not None:
            self.cloud_sync_done = cloud_sync_done
        self.finalize_start = finalize_start
        self.finalize_end = finalize_end
        self.recording_start = recording_start
        self.recording_end = recording_end
        self.gcode_file_name = gcode_file_name
        self.mp4_file = mp4_file
        self.user = user

    @property
    def id(self):
        """Gets the id of this VideoRecording.  # noqa: E501


        :return: The id of this VideoRecording.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this VideoRecording.


        :param id: The id of this VideoRecording.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def mp4_upload_url(self):
        """Gets the mp4_upload_url of this VideoRecording.  # noqa: E501


        :return: The mp4_upload_url of this VideoRecording.  # noqa: E501
        :rtype: str
        """
        return self._mp4_upload_url

    @mp4_upload_url.setter
    def mp4_upload_url(self, mp4_upload_url):
        """Sets the mp4_upload_url of this VideoRecording.


        :param mp4_upload_url: The mp4_upload_url of this VideoRecording.  # noqa: E501
        :type mp4_upload_url: str
        """
        if self.local_vars_configuration.client_side_validation and mp4_upload_url is None:  # noqa: E501
            raise ValueError("Invalid value for `mp4_upload_url`, must not be `None`")  # noqa: E501

        self._mp4_upload_url = mp4_upload_url

    @property
    def mp4_size(self):
        """Gets the mp4_size of this VideoRecording.  # noqa: E501


        :return: The mp4_size of this VideoRecording.  # noqa: E501
        :rtype: int
        """
        return self._mp4_size

    @mp4_size.setter
    def mp4_size(self, mp4_size):
        """Sets the mp4_size of this VideoRecording.


        :param mp4_size: The mp4_size of this VideoRecording.  # noqa: E501
        :type mp4_size: int
        """

        self._mp4_size = mp4_size

    @property
    def cloud_sync_done(self):
        """Gets the cloud_sync_done of this VideoRecording.  # noqa: E501


        :return: The cloud_sync_done of this VideoRecording.  # noqa: E501
        :rtype: bool
        """
        return self._cloud_sync_done

    @cloud_sync_done.setter
    def cloud_sync_done(self, cloud_sync_done):
        """Sets the cloud_sync_done of this VideoRecording.


        :param cloud_sync_done: The cloud_sync_done of this VideoRecording.  # noqa: E501
        :type cloud_sync_done: bool
        """

        self._cloud_sync_done = cloud_sync_done

    @property
    def finalize_start(self):
        """Gets the finalize_start of this VideoRecording.  # noqa: E501


        :return: The finalize_start of this VideoRecording.  # noqa: E501
        :rtype: datetime
        """
        return self._finalize_start

    @finalize_start.setter
    def finalize_start(self, finalize_start):
        """Sets the finalize_start of this VideoRecording.


        :param finalize_start: The finalize_start of this VideoRecording.  # noqa: E501
        :type finalize_start: datetime
        """

        self._finalize_start = finalize_start

    @property
    def finalize_end(self):
        """Gets the finalize_end of this VideoRecording.  # noqa: E501


        :return: The finalize_end of this VideoRecording.  # noqa: E501
        :rtype: datetime
        """
        return self._finalize_end

    @finalize_end.setter
    def finalize_end(self, finalize_end):
        """Sets the finalize_end of this VideoRecording.


        :param finalize_end: The finalize_end of this VideoRecording.  # noqa: E501
        :type finalize_end: datetime
        """

        self._finalize_end = finalize_end

    @property
    def recording_start(self):
        """Gets the recording_start of this VideoRecording.  # noqa: E501


        :return: The recording_start of this VideoRecording.  # noqa: E501
        :rtype: datetime
        """
        return self._recording_start

    @recording_start.setter
    def recording_start(self, recording_start):
        """Sets the recording_start of this VideoRecording.


        :param recording_start: The recording_start of this VideoRecording.  # noqa: E501
        :type recording_start: datetime
        """

        self._recording_start = recording_start

    @property
    def recording_end(self):
        """Gets the recording_end of this VideoRecording.  # noqa: E501


        :return: The recording_end of this VideoRecording.  # noqa: E501
        :rtype: datetime
        """
        return self._recording_end

    @recording_end.setter
    def recording_end(self, recording_end):
        """Sets the recording_end of this VideoRecording.


        :param recording_end: The recording_end of this VideoRecording.  # noqa: E501
        :type recording_end: datetime
        """

        self._recording_end = recording_end

    @property
    def gcode_file_name(self):
        """Gets the gcode_file_name of this VideoRecording.  # noqa: E501


        :return: The gcode_file_name of this VideoRecording.  # noqa: E501
        :rtype: str
        """
        return self._gcode_file_name

    @gcode_file_name.setter
    def gcode_file_name(self, gcode_file_name):
        """Sets the gcode_file_name of this VideoRecording.


        :param gcode_file_name: The gcode_file_name of this VideoRecording.  # noqa: E501
        :type gcode_file_name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                gcode_file_name is not None and len(gcode_file_name) > 255):
            raise ValueError("Invalid value for `gcode_file_name`, length must be less than or equal to `255`")  # noqa: E501

        self._gcode_file_name = gcode_file_name

    @property
    def mp4_file(self):
        """Gets the mp4_file of this VideoRecording.  # noqa: E501


        :return: The mp4_file of this VideoRecording.  # noqa: E501
        :rtype: str
        """
        return self._mp4_file

    @mp4_file.setter
    def mp4_file(self, mp4_file):
        """Sets the mp4_file of this VideoRecording.


        :param mp4_file: The mp4_file of this VideoRecording.  # noqa: E501
        :type mp4_file: str
        """

        self._mp4_file = mp4_file

    @property
    def user(self):
        """Gets the user of this VideoRecording.  # noqa: E501


        :return: The user of this VideoRecording.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this VideoRecording.


        :param user: The user of this VideoRecording.  # noqa: E501
        :type user: int
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoRecording):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VideoRecording):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.nats_organization import NatsOrganization  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestNatsOrganization(unittest.TestCase):
    """NatsOrganization unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test NatsOrganization
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.nats_organization.NatsOrganization()  # noqa: E501
        if include_optional :
            return NatsOrganization(
                id = 56, 
                name = '', 
                is_active = True, 
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                slug = 'z', 
                json = {
                    'key' : null
                    }, 
                jetstream_enabled = True, 
                jetstream_max_mem = '', 
                jetstream_max_file = '', 
                jetstream_max_streams = 0, 
                jetstream_max_consumers = 0, 
                imports = [
                    56
                    ], 
                exports = [
                    56
                    ], 
                users = [
                    56
                    ]
            )
        else :
            return NatsOrganization(
                id = 56,
                name = '',
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                slug = 'z',
                imports = [
                    56
                    ],
                exports = [
                    56
                    ],
                users = [
                    56
                    ],
        )

    def testNatsOrganization(self):
        """Test NatsOrganization"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.print_job_alert import PrintJobAlert  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestPrintJobAlert(unittest.TestCase):
    """PrintJobAlert unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PrintJobAlert
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.print_job_alert.PrintJobAlert()  # noqa: E501
        if include_optional :
            return PrintJobAlert(
                id = '', 
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                event_type = 'PrintQuality', 
                event_source = 'octoprint', 
                payload = {
                    'key' : null
                    }, 
                email_message_id = '', 
                image = '', 
                user = 56, 
                pi = 56
            )
        else :
            return PrintJobAlert(
                id = '',
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                event_type = 'PrintQuality',
                event_source = 'octoprint',
                user = 56,
                pi = 56,
        )

    def testPrintJobAlert(self):
        """Test PrintJobAlert"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.video_recording_part import VideoRecordingPart  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestVideoRecordingPart(unittest.TestCase):
    """VideoRecordingPart unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test VideoRecordingPart
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.video_recording_part.VideoRecordingPart()  # noqa: E501
        if include_optional :
            return VideoRecordingPart(
                id = '', 
                size = -9223372036854775808, 
                buffer_index = -9223372036854775808, 
                buffer_runningtime = -9223372036854775808, 
                file_name = '', 
                mp4_file = '', 
                sync_start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                sync_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                video_recording = '', 
                user = 56
            )
        else :
            return VideoRecordingPart(
                id = '',
                size = -9223372036854775808,
                buffer_index = -9223372036854775808,
                buffer_runningtime = -9223372036854775808,
                file_name = '',
                mp4_file = '',
                sync_start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                sync_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                video_recording = '',
                user = 56,
        )

    def testVideoRecordingPart(self):
        """Test VideoRecordingPart"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from printnanny_api_client.api_client import ApiClient
from printnanny_api_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class CrashReportsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def crash_reports_create(self, **kwargs):  # noqa: E501
        """crash_reports_create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.crash_reports_create(async_req=True)
        >>> result = thread.get()

        :param description:
        :type description: str
        :param email:
        :type email: str
        :param os_version:
        :type os_version: str
        :param os_logs:
        :type os_logs: file
        :param browser_version:
        :type browser_version: str
        :param browser_logs:
        :type browser_logs: file
        :param serial:
        :type serial: str
        :param posthog_session:
        :type posthog_session: str
        :param status:
        :type status: CrashReportStatusEnum
        :param support_comment:
        :type support_comment: str
        :param pi:
        :type pi: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CrashReport
        """
        kwargs['_return_http_data_only'] = True
        return self.crash_reports_create_with_http_info(**kwargs)  # noqa: E501

    def crash_reports_create_with_http_info(self, **kwargs):  # noqa: E501
        """crash_reports_create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.crash_reports_create_with_http_info(async_req=True)
        >>> result = thread.get()

        :param description:
        :type description: str
        :param email:
        :type email: str
        :param os_version:
        :type os_version: str
        :param os_logs:
        :type os_logs: file
        :param browser_version:
        :type browser_version: str
        :param browser_logs:
        :type browser_logs: file
        :param serial:
        :type serial: str
        :param posthog_session:
        :type posthog_session: str
        :param status:
        :type status: CrashReportStatusEnum
        :param support_comment:
        :type support_comment: str
        :param pi:
        :type pi: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CrashReport, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'description',
            'email',
            'os_version',
            'os_logs',
            'browser_version',
            'browser_logs',
            'serial',
            'posthog_session',
            'status',
            'support_comment',
            'pi'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method crash_reports_create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and ('email' in local_var_params and  # noqa: E501
                                                        len(local_var_params['email']) > 254):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `email` when calling `crash_reports_create`, length must be less than or equal to `254`")  # noqa: E501
        if self.api_client.client_side_validation and ('os_version' in local_var_params and  # noqa: E501
                                                        len(local_var_params['os_version']) > 255):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `os_version` when calling `crash_reports_create`, length must be less than or equal to `255`")  # noqa: E501
        if self.api_client.client_side_validation and ('browser_version' in local_var_params and  # noqa: E501
                                                        len(local_var_params['browser_version']) > 255):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `browser_version` when calling `crash_reports_create`, length must be less than or equal to `255`")  # noqa: E501
        if self.api_client.client_side_validation and ('serial' in local_var_params and  # noqa: E501
                                                        len(local_var_params['serial']) > 255):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `serial` when calling `crash_reports_create`, length must be less than or equal to `255`")  # noqa: E501
        if self.api_client.client_side_validation and ('posthog_session' in local_var_params and  # noqa: E501
                                                        len(local_var_params['posthog_session']) > 255):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `posthog_session` when calling `crash_reports_create`, length must be less than or equal to `255`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}
        if 'description' in local_var_params:
            form_params.append(('description', local_var_params['description']))  # noqa: E501
        if 'email' in local_var_params:
            form_params.append(('email', local_var_params['email']))  # noqa: E501
        if 'os_version' in local_var_params:
            form_params.append(('os_version', local_var_params['os_version']))  # noqa: E501
        if 'os_logs' in local_var_params:
            local_var_files['os_logs'] = local_var_params['os_logs']  # noqa: E501
        if 'browser_version' in local_var_params:
            form_params.append(('browser_version', local_var_params['browser_version']))  # noqa: E501
        if 'browser_logs' in local_var_params:
            local_var_files['browser_logs'] = local_var_params['browser_logs']  # noqa: E501
        if 'serial' in local_var_params:
            form_params.append(('serial', local_var_params['serial']))  # noqa: E501
        if 'posthog_session' in local_var_params:
            form_params.append(('posthog_session', local_var_params['posthog_session']))  # noqa: E501
        if 'status' in local_var_params:
            form_params.append(('status', local_var_params['status']))  # noqa: E501
        if 'support_comment' in local_var_params:
            form_params.append(('support_comment', local_var_params['support_comment']))  # noqa: E501
        if 'pi' in local_var_params:
            form_params.append(('pi', local_var_params['pi']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['multipart/form-data'],
                'POST', body_params))  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            201: "CrashReport",
            409: "ErrorDetail",
            400: "ErrorDetail",
            401: "ErrorDetail",
            403: "ErrorDetail",
            500: "ErrorDetail",
        }

        return self.api_client.call_api(
            '/api/crash-reports/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def crash_reports_list(self, **kwargs):  # noqa: E501
        """crash_reports_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.crash_reports_list(async_req=True)
        >>> result = thread.get()

        :param page: A page number within the paginated result set.
        :type page: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PaginatedCrashReportList
        """
        kwargs['_return_http_data_only'] = True
        return self.crash_reports_list_with_http_info(**kwargs)  # noqa: E501

    def crash_reports_list_with_http_info(self, **kwargs):  # noqa: E501
        """crash_reports_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.crash_reports_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param page: A page number within the paginated result set.
        :type page: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PaginatedCrashReportList, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'page'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method crash_reports_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            200: "PaginatedCrashReportList",
            400: "ErrorDetail",
            401: "ErrorDetail",
            403: "ErrorDetail",
            500: "ErrorDetail",
        }

        return self.api_client.call_api(
            '/api/crash-reports/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def crash_reports_partial_update(self, id, **kwargs):  # noqa: E501
        """crash_reports_partial_update  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.crash_reports_partial_update(id, async_req=True)
        >>> result = thread.get()

        :param id: A UUID string identifying this crash report. (required)
        :type id: str
        :param description:
        :type description: str
        :param email:
        :type email: str
        :param os_version:
        :type os_version: str
        :param os_logs:
        :type os_logs: file
        :param browser_version:
        :type browser_version: str
        :param browser_logs:
        :type browser_logs: file
        :param serial:
        :type serial: str
        :param posthog_session:
        :type posthog_session: str
        :param status:
        :type status: CrashReportStatusEnum
        :param support_comment:
        :type support_comment: str
        :param pi:
        :type pi: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CrashReport
        """
        kwargs['_return_http_data_only'] = True
        return self.crash_reports_partial_update_with_http_info(id, **kwargs)  # noqa: E501

    def crash_reports_partial_update_with_http_info(self, id, **kwargs):  # noqa: E501
        """crash_reports_partial_update  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.crash_reports_partial_update_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: A UUID string identifying this crash report. (required)
        :type id: str
        :param description:
        :type description: str
        :param email:
        :type email: str
        :param os_version:
        :type os_version: str
        :param os_logs:
        :type os_logs: file
        :param browser_version:
        :type browser_version: str
        :param browser_logs:
        :type browser_logs: file
        :param serial:
        :type serial: str
        :param posthog_session:
        :type posthog_session: str
        :param status:
        :type status: CrashReportStatusEnum
        :param support_comment:
        :type support_comment: str
        :param pi:
        :type pi: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CrashReport, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'id',
            'description',
            'email',
            'os_version',
            'os_logs',
            'browser_version',
            'browser_logs',
            'serial',
            'posthog_session',
            'status',
            'support_comment',
            'pi'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method crash_reports_partial_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `crash_reports_partial_update`")  # noqa: E501

        if self.api_client.client_side_validation and ('email' in local_var_params and  # noqa: E501
                                                        len(local_var_params['email']) > 254):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `email` when calling `crash_reports_partial_update`, length must be less than or equal to `254`")  # noqa: E501
        if self.api_client.client_side_validation and ('os_version' in local_var_params and  # noqa: E501
                                                        len(local_var_params['os_version']) > 255):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `os_version` when calling `crash_reports_partial_update`, length must be less than or equal to `255`")  # noqa: E501
        if self.api_client.client_side_validation and ('browser_version' in local_var_params and  # noqa: E501
                                                        len(local_var_params['browser_version']) > 255):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `browser_version` when calling `crash_reports_partial_update`, length must be less than or equal to `255`")  # noqa: E501
        if self.api_client.client_side_validation and ('serial' in local_var_params and  # noqa: E501
                                                        len(local_var_params['serial']) > 255):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `serial` when calling `crash_reports_partial_update`, length must be less than or equal to `255`")  # noqa: E501
        if self.api_client.client_side_validation and ('posthog_session' in local_var_params and  # noqa: E501
                                                        len(local_var_params['posthog_session']) > 255):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `posthog_session` when calling `crash_reports_partial_update`, length must be less than or equal to `255`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}
        if 'description' in local_var_params:
            form_params.append(('description', local_var_params['description']))  # noqa: E501
        if 'email' in local_var_params:
            form_params.append(('email', local_var_params['email']))  # noqa: E501
        if 'os_version' in local_var_params:
            form_params.append(('os_version', local_var_params['os_version']))  # noqa: E501
        if 'os_logs' in local_var_params:
            local_var_files['os_logs'] = local_var_params['os_logs']  # noqa: E501
        if 'browser_version' in local_var_params:
            form_params.append(('browser_version', local_var_params['browser_version']))  # noqa: E501
        if 'browser_logs' in local_var_params:
            local_var_files['browser_logs'] = local_var_params['browser_logs']  # noqa: E501
        if 'serial' in local_var_params:
            form_params.append(('serial', local_var_params['serial']))  # noqa: E501
        if 'posthog_session' in local_var_params:
            form_params.append(('posthog_session', local_var_params['posthog_session']))  # noqa: E501
        if 'status' in local_var_params:
            form_params.append(('status', local_var_params['status']))  # noqa: E501
        if 'support_comment' in local_var_params:
            form_params.append(('support_comment', local_var_params['support_comment']))  # noqa: E501
        if 'pi' in local_var_params:
            form_params.append(('pi', local_var_params['pi']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['multipart/form-data'],
                'PATCH', body_params))  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            202: "CrashReport",
            409: "ErrorDetail",
            400: "ErrorDetail",
            401: "ErrorDetail",
            403: "ErrorDetail",
            500: "ErrorDetail",
        }

        return self.api_client.call_api(
            '/api/crash-reports/{id}/', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def crash_reports_retrieve(self, id, **kwargs):  # noqa: E501
        """crash_reports_retrieve  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.crash_reports_retrieve(id, async_req=True)
        >>> result = thread.get()

        :param id: A UUID string identifying this crash report. (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CrashReport
        """
        kwargs['_return_http_data_only'] = True
        return self.crash_reports_retrieve_with_http_info(id, **kwargs)  # noqa: E501

    def crash_reports_retrieve_with_http_info(self, id, **kwargs):  # noqa: E501
        """crash_reports_retrieve  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.crash_reports_retrieve_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: A UUID string identifying this crash report. (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CrashReport, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method crash_reports_retrieve" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `crash_reports_retrieve`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            200: "CrashReport",
        }

        return self.api_client.call_api(
            '/api/crash-reports/{id}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def crash_reports_update(self, id, **kwargs):  # noqa: E501
        """crash_reports_update  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.crash_reports_update(id, async_req=True)
        >>> result = thread.get()

        :param id: A UUID string identifying this crash report. (required)
        :type id: str
        :param description:
        :type description: str
        :param email:
        :type email: str
        :param os_version:
        :type os_version: str
        :param os_logs:
        :type os_logs: file
        :param browser_version:
        :type browser_version: str
        :param browser_logs:
        :type browser_logs: file
        :param serial:
        :type serial: str
        :param posthog_session:
        :type posthog_session: str
        :param status:
        :type status: CrashReportStatusEnum
        :param support_comment:
        :type support_comment: str
        :param pi:
        :type pi: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CrashReport
        """
        kwargs['_return_http_data_only'] = True
        return self.crash_reports_update_with_http_info(id, **kwargs)  # noqa: E501

    def crash_reports_update_with_http_info(self, id, **kwargs):  # noqa: E501
        """crash_reports_update  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.crash_reports_update_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: A UUID string identifying this crash report. (required)
        :type id: str
        :param description:
        :type description: str
        :param email:
        :type email: str
        :param os_version:
        :type os_version: str
        :param os_logs:
        :type os_logs: file
        :param browser_version:
        :type browser_version: str
        :param browser_logs:
        :type browser_logs: file
        :param serial:
        :type serial: str
        :param posthog_session:
        :type posthog_session: str
        :param status:
        :type status: CrashReportStatusEnum
        :param support_comment:
        :type support_comment: str
        :param pi:
        :type pi: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CrashReport, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'id',
            'description',
            'email',
            'os_version',
            'os_logs',
            'browser_version',
            'browser_logs',
            'serial',
            'posthog_session',
            'status',
            'support_comment',
            'pi'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method crash_reports_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `crash_reports_update`")  # noqa: E501

        if self.api_client.client_side_validation and ('email' in local_var_params and  # noqa: E501
                                                        len(local_var_params['email']) > 254):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `email` when calling `crash_reports_update`, length must be less than or equal to `254`")  # noqa: E501
        if self.api_client.client_side_validation and ('os_version' in local_var_params and  # noqa: E501
                                                        len(local_var_params['os_version']) > 255):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `os_version` when calling `crash_reports_update`, length must be less than or equal to `255`")  # noqa: E501
        if self.api_client.client_side_validation and ('browser_version' in local_var_params and  # noqa: E501
                                                        len(local_var_params['browser_version']) > 255):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `browser_version` when calling `crash_reports_update`, length must be less than or equal to `255`")  # noqa: E501
        if self.api_client.client_side_validation and ('serial' in local_var_params and  # noqa: E501
                                                        len(local_var_params['serial']) > 255):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `serial` when calling `crash_reports_update`, length must be less than or equal to `255`")  # noqa: E501
        if self.api_client.client_side_validation and ('posthog_session' in local_var_params and  # noqa: E501
                                                        len(local_var_params['posthog_session']) > 255):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `posthog_session` when calling `crash_reports_update`, length must be less than or equal to `255`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}
        if 'description' in local_var_params:
            form_params.append(('description', local_var_params['description']))  # noqa: E501
        if 'email' in local_var_params:
            form_params.append(('email', local_var_params['email']))  # noqa: E501
        if 'os_version' in local_var_params:
            form_params.append(('os_version', local_var_params['os_version']))  # noqa: E501
        if 'os_logs' in local_var_params:
            local_var_files['os_logs'] = local_var_params['os_logs']  # noqa: E501
        if 'browser_version' in local_var_params:
            form_params.append(('browser_version', local_var_params['browser_version']))  # noqa: E501
        if 'browser_logs' in local_var_params:
            local_var_files['browser_logs'] = local_var_params['browser_logs']  # noqa: E501
        if 'serial' in local_var_params:
            form_params.append(('serial', local_var_params['serial']))  # noqa: E501
        if 'posthog_session' in local_var_params:
            form_params.append(('posthog_session', local_var_params['posthog_session']))  # noqa: E501
        if 'status' in local_var_params:
            form_params.append(('status', local_var_params['status']))  # noqa: E501
        if 'support_comment' in local_var_params:
            form_params.append(('support_comment', local_var_params['support_comment']))  # noqa: E501
        if 'pi' in local_var_params:
            form_params.append(('pi', local_var_params['pi']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['multipart/form-data'],
                'PUT', body_params))  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            202: "CrashReport",
            409: "ErrorDetail",
            400: "ErrorDetail",
            401: "ErrorDetail",
            403: "ErrorDetail",
            500: "ErrorDetail",
        }

        return self.api_client.call_api(
            '/api/crash-reports/{id}/', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import printnanny_api_client
from printnanny_api_client.api.videos_api import VideosApi  # noqa: E501
from printnanny_api_client.rest import ApiException


class TestVideosApi(unittest.TestCase):
    """VideosApi unit test stubs"""

    def setUp(self):
        self.api = printnanny_api_client.api.videos_api.VideosApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_video_parts_create(self):
        """Test case for video_parts_create

        """
        pass

    def test_video_parts_list(self):
        """Test case for video_parts_list

        """
        pass

    def test_video_parts_retrieve(self):
        """Test case for video_parts_retrieve

        """
        pass

    def test_video_recordings_update_or_create(self):
        """Test case for video_recordings_update_or_create

        """
        pass

    def test_videos_create(self):
        """Test case for videos_create

        """
        pass

    def test_videos_list(self):
        """Test case for videos_list

        """
        pass

    def test_videos_partial_update(self):
        """Test case for videos_partial_update

        """
        pass

    def test_videos_retrieve(self):
        """Test case for videos_retrieve

        """
        pass

    def test_videos_update(self):
        """Test case for videos_update

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class CrashReport(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'url': 'str',
        'created_dt': 'datetime',
        'updated_dt': 'datetime',
        'description': 'str',
        'email': 'str',
        'os_version': 'str',
        'os_logs': 'str',
        'browser_version': 'str',
        'browser_logs': 'str',
        'serial': 'str',
        'posthog_session': 'str',
        'status': 'CrashReportStatusEnum',
        'support_comment': 'str',
        'user': 'int',
        'pi': 'int'
    }

    attribute_map = {
        'id': 'id',
        'url': 'url',
        'created_dt': 'created_dt',
        'updated_dt': 'updated_dt',
        'description': 'description',
        'email': 'email',
        'os_version': 'os_version',
        'os_logs': 'os_logs',
        'browser_version': 'browser_version',
        'browser_logs': 'browser_logs',
        'serial': 'serial',
        'posthog_session': 'posthog_session',
        'status': 'status',
        'support_comment': 'support_comment',
        'user': 'user',
        'pi': 'pi'
    }

    def __init__(self, id=None, url=None, created_dt=None, updated_dt=None, description=None, email=None, os_version=None, os_logs=None, browser_version=None, browser_logs=None, serial=None, posthog_session=None, status=None, support_comment=None, user=None, pi=None, local_vars_configuration=None):  # noqa: E501
        """CrashReport - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._url = None
        self._created_dt = None
        self._updated_dt = None
        self._description = None
        self._email = None
        self._os_version = None
        self._os_logs = None
        self._browser_version = None
        self._browser_logs = None
        self._serial = None
        self._posthog_session = None
        self._status = None
        self._support_comment = None
        self._user = None
        self._pi = None
        self.discriminator = None

        self.id = id
        self.url = url
        self.created_dt = created_dt
        self.updated_dt = updated_dt
        self.description = description
        self.email = email
        self.os_version = os_version
        self.os_logs = os_logs
        self.browser_version = browser_version
        self.browser_logs = browser_logs
        self.serial = serial
        self.posthog_session = posthog_session
        if status is not None:
            self.status = status
        self.support_comment = support_comment
        self.user = user
        self.pi = pi

    @property
    def id(self):
        """Gets the id of this CrashReport.  # noqa: E501


        :return: The id of this CrashReport.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CrashReport.


        :param id: The id of this CrashReport.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def url(self):
        """Gets the url of this CrashReport.  # noqa: E501


        :return: The url of this CrashReport.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this CrashReport.


        :param url: The url of this CrashReport.  # noqa: E501
        :type url: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def created_dt(self):
        """Gets the created_dt of this CrashReport.  # noqa: E501


        :return: The created_dt of this CrashReport.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this CrashReport.


        :param created_dt: The created_dt of this CrashReport.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def updated_dt(self):
        """Gets the updated_dt of this CrashReport.  # noqa: E501


        :return: The updated_dt of this CrashReport.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this CrashReport.


        :param updated_dt: The updated_dt of this CrashReport.  # noqa: E501
        :type updated_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    @property
    def description(self):
        """Gets the description of this CrashReport.  # noqa: E501


        :return: The description of this CrashReport.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CrashReport.


        :param description: The description of this CrashReport.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def email(self):
        """Gets the email of this CrashReport.  # noqa: E501


        :return: The email of this CrashReport.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this CrashReport.


        :param email: The email of this CrashReport.  # noqa: E501
        :type email: str
        """
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) > 254):
            raise ValueError("Invalid value for `email`, length must be less than or equal to `254`")  # noqa: E501

        self._email = email

    @property
    def os_version(self):
        """Gets the os_version of this CrashReport.  # noqa: E501


        :return: The os_version of this CrashReport.  # noqa: E501
        :rtype: str
        """
        return self._os_version

    @os_version.setter
    def os_version(self, os_version):
        """Sets the os_version of this CrashReport.


        :param os_version: The os_version of this CrashReport.  # noqa: E501
        :type os_version: str
        """
        if (self.local_vars_configuration.client_side_validation and
                os_version is not None and len(os_version) > 255):
            raise ValueError("Invalid value for `os_version`, length must be less than or equal to `255`")  # noqa: E501

        self._os_version = os_version

    @property
    def os_logs(self):
        """Gets the os_logs of this CrashReport.  # noqa: E501


        :return: The os_logs of this CrashReport.  # noqa: E501
        :rtype: str
        """
        return self._os_logs

    @os_logs.setter
    def os_logs(self, os_logs):
        """Sets the os_logs of this CrashReport.


        :param os_logs: The os_logs of this CrashReport.  # noqa: E501
        :type os_logs: str
        """

        self._os_logs = os_logs

    @property
    def browser_version(self):
        """Gets the browser_version of this CrashReport.  # noqa: E501


        :return: The browser_version of this CrashReport.  # noqa: E501
        :rtype: str
        """
        return self._browser_version

    @browser_version.setter
    def browser_version(self, browser_version):
        """Sets the browser_version of this CrashReport.


        :param browser_version: The browser_version of this CrashReport.  # noqa: E501
        :type browser_version: str
        """
        if (self.local_vars_configuration.client_side_validation and
                browser_version is not None and len(browser_version) > 255):
            raise ValueError("Invalid value for `browser_version`, length must be less than or equal to `255`")  # noqa: E501

        self._browser_version = browser_version

    @property
    def browser_logs(self):
        """Gets the browser_logs of this CrashReport.  # noqa: E501


        :return: The browser_logs of this CrashReport.  # noqa: E501
        :rtype: str
        """
        return self._browser_logs

    @browser_logs.setter
    def browser_logs(self, browser_logs):
        """Sets the browser_logs of this CrashReport.


        :param browser_logs: The browser_logs of this CrashReport.  # noqa: E501
        :type browser_logs: str
        """

        self._browser_logs = browser_logs

    @property
    def serial(self):
        """Gets the serial of this CrashReport.  # noqa: E501


        :return: The serial of this CrashReport.  # noqa: E501
        :rtype: str
        """
        return self._serial

    @serial.setter
    def serial(self, serial):
        """Sets the serial of this CrashReport.


        :param serial: The serial of this CrashReport.  # noqa: E501
        :type serial: str
        """
        if (self.local_vars_configuration.client_side_validation and
                serial is not None and len(serial) > 255):
            raise ValueError("Invalid value for `serial`, length must be less than or equal to `255`")  # noqa: E501

        self._serial = serial

    @property
    def posthog_session(self):
        """Gets the posthog_session of this CrashReport.  # noqa: E501


        :return: The posthog_session of this CrashReport.  # noqa: E501
        :rtype: str
        """
        return self._posthog_session

    @posthog_session.setter
    def posthog_session(self, posthog_session):
        """Sets the posthog_session of this CrashReport.


        :param posthog_session: The posthog_session of this CrashReport.  # noqa: E501
        :type posthog_session: str
        """
        if (self.local_vars_configuration.client_side_validation and
                posthog_session is not None and len(posthog_session) > 255):
            raise ValueError("Invalid value for `posthog_session`, length must be less than or equal to `255`")  # noqa: E501

        self._posthog_session = posthog_session

    @property
    def status(self):
        """Gets the status of this CrashReport.  # noqa: E501


        :return: The status of this CrashReport.  # noqa: E501
        :rtype: CrashReportStatusEnum
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CrashReport.


        :param status: The status of this CrashReport.  # noqa: E501
        :type status: CrashReportStatusEnum
        """

        self._status = status

    @property
    def support_comment(self):
        """Gets the support_comment of this CrashReport.  # noqa: E501


        :return: The support_comment of this CrashReport.  # noqa: E501
        :rtype: str
        """
        return self._support_comment

    @support_comment.setter
    def support_comment(self, support_comment):
        """Sets the support_comment of this CrashReport.


        :param support_comment: The support_comment of this CrashReport.  # noqa: E501
        :type support_comment: str
        """

        self._support_comment = support_comment

    @property
    def user(self):
        """Gets the user of this CrashReport.  # noqa: E501


        :return: The user of this CrashReport.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this CrashReport.


        :param user: The user of this CrashReport.  # noqa: E501
        :type user: int
        """

        self._user = user

    @property
    def pi(self):
        """Gets the pi of this CrashReport.  # noqa: E501


        :return: The pi of this CrashReport.  # noqa: E501
        :rtype: int
        """
        return self._pi

    @pi.setter
    def pi(self, pi):
        """Sets the pi of this CrashReport.


        :param pi: The pi of this CrashReport.  # noqa: E501
        :type pi: int
        """

        self._pi = pi

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CrashReport):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CrashReport):
            return True

        return self.to_dict() != other.to_dict()
